'''
	This file is part of PAScual.
    PAScual: Positron Annihilation Spectroscopy data analysis
    Copyright (C) 2007  Carlos Pascual-Izarra < cpascual [AT] users.sourceforge.net >

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
'''

'''
Some convenience classes are defined to work with loading spectra in various formats.
'''

import scipy as S


class spectrumFileLoader(object):
    '''This is an abstract class for implementing derived File Loader classes'''

    def __init__(self, name=''):
        self.name = name
        self.formatDescription = ''
        self.filenamefilter = '*'
        self.needExtraInput = False

    def expdata(self, fname):
        '''This function has to be implemented in the derived classes.
        It gets the file name of the file to read
        It must return an array of doubles containing the spectrum yields (or None if it couldn t load)'''
        return None

    def getDiscretePals(self, fname):
        '''This function has to be implemented in the derived classes.
        It gets the file name of the file to read
        It must return discretepals object (or None if it couldn t load)'''
        return None

    def askExtraInput(self):
        pass


class MAESTROfileLoader(spectrumFileLoader):
    def __init__(self, name='MAESTRO'):
        spectrumFileLoader.__init__(self, name)
        self.formatDescription = 'Binary format from Ortec'
        self.filenamefilter = '*.chn'

    def expdata(self, fname):
        import CHNfiles
        hdr, expdata = CHNfiles.CHN.readCHN(fname)
        return S.array(expdata, dtype='d')


class ASCIIfileloader(spectrumFileLoader):
    def __init__(self, name='ASCII', filenamefilter='*', hdrlines=None,
                 description=None, askmode='t', Qtparent=None):
        spectrumFileLoader.__init__(self, name)
        self.filenamefilter = filenamefilter
        if description is None:
            self.formatDescription = 'File containing yields separated by any blank space'
        else:
            self.formatDescription = description
        self.hdrlns = hdrlines
        if self.hdrlns is None: self.needExtraInput = True
        self.askmode = askmode
        self.Qtparent = Qtparent

    def expdata(self, fname):
        if self.hdrlns is None: self.needExtraInput = True
        if self.needExtraInput: self.askExtraInput()
        expdata = S.loadtxt(fname, skiprows=self.hdrlns, dtype='d').flatten()
        return expdata

    def askExtraInput(self, mode='t'):
        '''It asks for the header lines to skip using either text (mode="t")or Qt (mode="qt") interface.'''
        if self.askmode == 't':
            # asks in text mode
            self.hdrlns = self.int(
                raw_input('Number of lines to skip in the header?'))
            okflag = True
        if self.askmode == 'qt':
            # Asks via a qt dialog. This assumes that Qt is installed. You must provide a parent for the dialog
            from PyQt4.QtGui import QInputDialog
            if self.hdrlns is None:
                dflt = 0
            else:
                dflt = self.hdrlns
            self.hdrlns, okflag = QInputDialog.getInteger(self.Qtparent,
                                                          "Header lines?",
                                                          "Number of lines to skip in the header:",
                                                          dflt, 0, 999, 1)
        return okflag


class PAScualfileLoader(spectrumFileLoader):
    def __init__(self, name='PAScual'):
        spectrumFileLoader.__init__(self, name)
        self.formatDescription = 'Pickled Spectrum from PAScual'
        self.filenamefilter = '*.ps1'

    def getDiscretePals(self, fname):
        import pickle
        dp = pickle.load(open(fname, 'rb'))
        return dp

    def expdata(self, fname):
        dp = self.getDiscretePals(fname)
        return S.array(dp.exp, dtype='d')



'''
	TEcalcGUI: Graphical User Interface for the Tao Eldrup Calculator
    PAScual: Positron Annihilation Spectroscopy data analysis
    Copyright (C) 2007  Carlos Pascual-Izarra < cpascual [AT] users.sourceforge.net >

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
'''
import sys

from PyQt4.QtCore import *
from PyQt4.QtGui import *

import ui_TEcalcGUI
from pyTaoEldrup import *


class TEcalcDialog(QDialog, ui_TEcalcGUI.Ui_TEcalcGUI):
    def __init__(self, parent=None):
        super(TEcalcDialog, self).__init__(parent)
        self.setupUi(self)
        # 		self.resultsTable.clear()

        # Adding actions
        self.resultsTable.addActions(
            [self.actionCopy_Results_Selection])  # context menu

        # connections
        QObject.connect(self.CalculatePB, SIGNAL("clicked()"), self.onCalculate)
        QObject.connect(self.actionCopy_Results_Selection,
                        SIGNAL("triggered()"), self.copy_Results_Selection)

    def onCalculate(self):
        '''Launches the calculation'''
        # read the input
        tau = unicode(self.tauTE.toPlainText()).replace(';',
                                                        ' ').split()  # semicolons are also valid separators (apart from blank space)
        T = unicode(self.TempTE.toPlainText()).replace(';',
                                                       ' ').split()  # semicolons are also valid separators (apart from blank space)
        try:
            tau = S.array([float(elem) for elem in tau], dtype='d')
            T = S.array([float(elem) for elem in T], dtype='d')
        except ValueError:
            QMessageBox.critical(self, "Bad input",
                                 " The input for the lifetime/temperature must be a number or sequence of numbers")
            return
        # Check input lengths
        if tau.size == 0:
            QMessageBox.critical(self, "No input",
                                 " You must provide at least one lifetime value")
            return
        if self.GeomSphereRB.isChecked(): T = S.zeros(
            tau.size)  # Temp is not used in this model
        if T.size == 0:
            QMessageBox.critical(self, "No input",
                                 " You must provide at least one temperature value for this geometry")
            return
        if tau.size > 1 and T.size == 1 and not self.sameTempCB.isChecked():
            answer = QMessageBox.warning(self, "Same temperature?",
                                         "Do you want to use T=%g for all the lifetimes?" %
                                         T[0],
                                         QMessageBox.Yes | QMessageBox.Cancel)
            if answer == QMessageBox.Yes:
                self.sameTempCB.setChecked(True)
            else:
                return
        if self.sameTempCB.isChecked() and self.sameTempCB.isEnabled():
            if T.size == 1:
                T = T[0] * S.ones(tau.size)
            else:
                QMessageBox.critical(self, "Bad Input",
                                     """Give an unique temperature or uncheck the "same temp" option""")
                return

        if T.size != tau.size:
            QMessageBox.critical(self, "Bad input",
                                 " The number of lifetimes (%i) does not match the number of temperatures (%i)" % (
                                 tau.size, T.size))
            return

        # Deal with units (the pyTaoEldrup module works internally with ns and Kelvin
        if self.psRB.isChecked(): tau *= 1e-3
        if self.celsiusRB.isChecked(): T += 273.

        # check for unphysical inputs
        if tau.min() < .5 or T.min() < 0 or tau.max() > 142:
            QMessageBox.critical(self, "Bad input",
                                 " One or more inputs are unphysical \n(check for negative absolute temperatures or lifetimes outside the 1-142 ns range) ")
            return

        # Do the calculations
        size = S.zeros(tau.size)
        badcalcsflag = False
        for i in range(tau.size):
            try:
                if self.GeomSphereRB.isChecked():
                    size[i] = TE_radius(tau[i])
                    if self.softwallsCB.isChecked(): size[i] += TE_softwall
                elif self.GeomEquivSphRB.isChecked():
                    a = RTE_cube(tau[i], T[i])
                    size[
                        i] = a / 2. - TE_softwall  # this gives the radius of an sphere with equivalent mean free path to the calculated cube
                    if self.softwallsCB.isChecked(): size[i] += TE_softwall
                elif self.GeomCubeRB.isChecked():
                    size[i] = RTE_cube(tau[i], T[i])
                    if not self.softwallsCB.isChecked(): size[
                        i] -= 2 * RTE_softwall
                elif self.GeomChannelRB.isChecked():
                    size[i] = RTE_channel(tau[i], T[i])
                    if not self.softwallsCB.isChecked(): size[
                        i] -= 2 * RTE_softwall
                elif self.GeomSheetRB.isChecked():
                    size[i] = RTE_sheet(tau[i], T[i])
                    if not self.softwallsCB.isChecked(): size[
                        i] -= 2 * RTE_softwall
            except:
                badcalcsflag = True

        if size.min() < 0: badcalcsflag = True

        if badcalcsflag:
            QMessageBox.warning(self, "Possible bad results",
                                " One or more results may not be correct due to bad inversion of the (R)TE formula")

        # Show the calculation:

        # headers
        self.resultsHeader = 3 * [""]
        if self.psRB.isChecked():
            self.resultsHeader[0] = "Lifetime (ps)"
            tau *= 1000
        else:
            self.resultsHeader[0] = "Lifetime (ns)"
        if self.celsiusRB.isChecked():
            self.resultsHeader[1] = "Temperature (C)"
            T -= 273
        else:
            self.resultsHeader[1] = "Temperature (K)"

        if self.GeomSphereRB.isChecked():
            self.resultsHeader[2] = "TE Sphere radius (nm)"
        elif self.GeomEquivSphRB.isChecked():
            self.resultsHeader[2] = "RTE Equivalent radius (nm)"
        elif self.GeomCubeRB.isChecked():
            self.resultsHeader[2] = "Cube side (nm)"
        elif self.GeomChannelRB.isChecked():
            self.resultsHeader[2] = "Sq. channel side (nm)"
        elif self.GeomSheetRB.isChecked():
            self.resultsHeader[2] = "Sheet spacing (nm)"

        # 		print tau,T,size

        # fill table
        self.resultsTable.clear()
        self.resultsTable.setHorizontalHeaderLabels(self.resultsHeader)
        self.resultsTable.resizeColumnsToContents()
        self.resultsTable.setRowCount(tau.size)
        for i in xrange(tau.size):
            self.resultsTable.setItem(i, 0, QTableWidgetItem("%g" % tau[i]))
            self.resultsTable.setItem(i, 1, QTableWidgetItem("%g" % T[i]))
            self.resultsTable.setItem(i, 2, QTableWidgetItem("%g" % size[i]))

    def copy_Results_Selection(self):
        '''copies the selected results to the clipboard'''
        string = ''
        selecteditems = self.resultsTable.selectedItems()
        for i in range(self.resultsTable.rowCount()):
            emptyrow = True
            for j in range(self.resultsTable.columnCount()):
                if self.resultsTable.item(i, j) in selecteditems:
                    if emptyrow:
                        string += '\n%s' % self.resultsTable.item(i, j).text()
                    else:
                        string += '\t%s' % self.resultsTable.item(i, j).text()
                    emptyrow = False
        QApplication.clipboard().setText(string.strip())


def main():
    app = QApplication(sys.argv)
    form = TEcalcDialog()
    form.show()
    sys.exit(app.exec_())

if __name__ == "__main__":
    main()


# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'C:\Documents and Settings\pas064\My Documents\src\PAScual-dev\TEcalcGUI.ui'
#
# Created: Wed Jul 02 16:05:18 2008
#      by: PyQt4 UI code generator 4.4.2
#
# WARNING! All changes made in this file will be lost!

from PyQt4 import QtCore, QtGui


class Ui_TEcalcGUI(object):
    def setupUi(self, TEcalcGUI):
        TEcalcGUI.setObjectName("TEcalcGUI")
        TEcalcGUI.resize(487, 574)
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/Icons/icons/mine/TaoEldrup32x32.png"),
                       QtGui.QIcon.Normal, QtGui.QIcon.Off)
        TEcalcGUI.setWindowIcon(icon)
        self.vboxlayout = QtGui.QVBoxLayout(TEcalcGUI)
        self.vboxlayout.setObjectName("vboxlayout")
        self.groupBox_2 = QtGui.QGroupBox(TEcalcGUI)
        self.groupBox_2.setObjectName("groupBox_2")
        self.gridlayout = QtGui.QGridLayout(self.groupBox_2)
        self.gridlayout.setObjectName("gridlayout")
        self.frame = QtGui.QFrame(self.groupBox_2)
        self.frame.setFrameShape(QtGui.QFrame.StyledPanel)
        self.frame.setFrameShadow(QtGui.QFrame.Raised)
        self.frame.setObjectName("frame")
        self.vboxlayout1 = QtGui.QVBoxLayout(self.frame)
        self.vboxlayout1.setObjectName("vboxlayout1")
        self.label = QtGui.QLabel(self.frame)
        self.label.setObjectName("label")
        self.vboxlayout1.addWidget(self.label)
        self.nsRB = QtGui.QRadioButton(self.frame)
        self.nsRB.setChecked(True)
        self.nsRB.setObjectName("nsRB")
        self.vboxlayout1.addWidget(self.nsRB)
        self.psRB = QtGui.QRadioButton(self.frame)
        self.psRB.setObjectName("psRB")
        self.vboxlayout1.addWidget(self.psRB)
        self.gridlayout.addWidget(self.frame, 0, 0, 1, 1)
        self.frame_3 = QtGui.QFrame(self.groupBox_2)
        self.frame_3.setEnabled(False)
        self.frame_3.setFrameShape(QtGui.QFrame.StyledPanel)
        self.frame_3.setFrameShadow(QtGui.QFrame.Raised)
        self.frame_3.setObjectName("frame_3")
        self.vboxlayout2 = QtGui.QVBoxLayout(self.frame_3)
        self.vboxlayout2.setObjectName("vboxlayout2")
        self.label_2 = QtGui.QLabel(self.frame_3)
        self.label_2.setObjectName("label_2")
        self.vboxlayout2.addWidget(self.label_2)
        self.kelvinRB = QtGui.QRadioButton(self.frame_3)
        self.kelvinRB.setChecked(True)
        self.kelvinRB.setObjectName("kelvinRB")
        self.vboxlayout2.addWidget(self.kelvinRB)
        self.celsiusRB = QtGui.QRadioButton(self.frame_3)
        self.celsiusRB.setChecked(False)
        self.celsiusRB.setObjectName("celsiusRB")
        self.vboxlayout2.addWidget(self.celsiusRB)
        self.gridlayout.addWidget(self.frame_3, 0, 1, 1, 1)
        self.groupBox = QtGui.QGroupBox(self.groupBox_2)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Preferred,
                                       QtGui.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(
            self.groupBox.sizePolicy().hasHeightForWidth())
        self.groupBox.setSizePolicy(sizePolicy)
        self.groupBox.setMinimumSize(QtCore.QSize(0, 0))
        self.groupBox.setObjectName("groupBox")
        self.vboxlayout3 = QtGui.QVBoxLayout(self.groupBox)
        self.vboxlayout3.setObjectName("vboxlayout3")
        self.GeomSphereRB = QtGui.QRadioButton(self.groupBox)
        self.GeomSphereRB.setChecked(True)
        self.GeomSphereRB.setObjectName("GeomSphereRB")
        self.vboxlayout3.addWidget(self.GeomSphereRB)
        self.GeomEquivSphRB = QtGui.QRadioButton(self.groupBox)
        self.GeomEquivSphRB.setEnabled(True)
        self.GeomEquivSphRB.setChecked(False)
        self.GeomEquivSphRB.setObjectName("GeomEquivSphRB")
        self.vboxlayout3.addWidget(self.GeomEquivSphRB)
        self.GeomCubeRB = QtGui.QRadioButton(self.groupBox)
        self.GeomCubeRB.setObjectName("GeomCubeRB")
        self.vboxlayout3.addWidget(self.GeomCubeRB)
        self.GeomChannelRB = QtGui.QRadioButton(self.groupBox)
        self.GeomChannelRB.setObjectName("GeomChannelRB")
        self.vboxlayout3.addWidget(self.GeomChannelRB)
        self.GeomSheetRB = QtGui.QRadioButton(self.groupBox)
        self.GeomSheetRB.setObjectName("GeomSheetRB")
        self.vboxlayout3.addWidget(self.GeomSheetRB)
        self.softwallsCB = QtGui.QCheckBox(self.groupBox)
        self.softwallsCB.setObjectName("softwallsCB")
        self.vboxlayout3.addWidget(self.softwallsCB)
        self.gridlayout.addWidget(self.groupBox, 0, 2, 2, 1)
        self.tauTE = QtGui.QTextEdit(self.groupBox_2)
        self.tauTE.setObjectName("tauTE")
        self.gridlayout.addWidget(self.tauTE, 1, 0, 1, 1)
        self.TempTE = QtGui.QTextEdit(self.groupBox_2)
        self.TempTE.setEnabled(False)
        self.TempTE.setObjectName("TempTE")
        self.gridlayout.addWidget(self.TempTE, 1, 1, 1, 1)
        self.sameTempCB = QtGui.QCheckBox(self.groupBox_2)
        self.sameTempCB.setEnabled(False)
        self.sameTempCB.setObjectName("sameTempCB")
        self.gridlayout.addWidget(self.sameTempCB, 2, 1, 1, 1)
        self.hboxlayout = QtGui.QHBoxLayout()
        self.hboxlayout.setObjectName("hboxlayout")
        spacerItem = QtGui.QSpacerItem(40, 20, QtGui.QSizePolicy.Expanding,
                                       QtGui.QSizePolicy.Minimum)
        self.hboxlayout.addItem(spacerItem)
        self.ClearPB = QtGui.QPushButton(self.groupBox_2)
        self.ClearPB.setObjectName("ClearPB")
        self.hboxlayout.addWidget(self.ClearPB)
        self.gridlayout.addLayout(self.hboxlayout, 2, 2, 1, 1)
        self.vboxlayout.addWidget(self.groupBox_2)
        self.groupBox_3 = QtGui.QGroupBox(TEcalcGUI)
        self.groupBox_3.setObjectName("groupBox_3")
        self.vboxlayout4 = QtGui.QVBoxLayout(self.groupBox_3)
        self.vboxlayout4.setObjectName("vboxlayout4")
        self.resultsTable = QtGui.QTableWidget(self.groupBox_3)
        self.resultsTable.setContextMenuPolicy(QtCore.Qt.ActionsContextMenu)
        self.resultsTable.setEditTriggers(
            QtGui.QAbstractItemView.NoEditTriggers)
        self.resultsTable.setSortingEnabled(False)
        self.resultsTable.setObjectName("resultsTable")
        self.vboxlayout4.addWidget(self.resultsTable)
        self.vboxlayout.addWidget(self.groupBox_3)
        self.hboxlayout1 = QtGui.QHBoxLayout()
        self.hboxlayout1.setObjectName("hboxlayout1")
        spacerItem1 = QtGui.QSpacerItem(40, 20, QtGui.QSizePolicy.Expanding,
                                        QtGui.QSizePolicy.Minimum)
        self.hboxlayout1.addItem(spacerItem1)
        self.CalculatePB = QtGui.QPushButton(TEcalcGUI)
        self.CalculatePB.setObjectName("CalculatePB")
        self.hboxlayout1.addWidget(self.CalculatePB)
        self.vboxlayout.addLayout(self.hboxlayout1)
        self.actionCopy_Results_Selection = QtGui.QAction(TEcalcGUI)
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/Icons/icons/mine/TaoEldrup64x64.png"),
                       QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionCopy_Results_Selection.setIcon(icon)
        self.actionCopy_Results_Selection.setObjectName(
            "actionCopy_Results_Selection")

        self.retranslateUi(TEcalcGUI)
        QtCore.QObject.connect(self.ClearPB, QtCore.SIGNAL("clicked()"),
                               self.TempTE.clear)
        QtCore.QObject.connect(self.ClearPB, QtCore.SIGNAL("clicked()"),
                               self.tauTE.clear)
        QtCore.QObject.connect(self.GeomSphereRB,
                               QtCore.SIGNAL("toggled(bool)"),
                               self.TempTE.setDisabled)
        QtCore.QObject.connect(self.GeomSphereRB,
                               QtCore.SIGNAL("toggled(bool)"),
                               self.sameTempCB.setDisabled)
        QtCore.QObject.connect(self.GeomSphereRB,
                               QtCore.SIGNAL("toggled(bool)"),
                               self.frame_3.setDisabled)
        QtCore.QObject.connect(self.ClearPB, QtCore.SIGNAL("clicked()"),
                               self.resultsTable.clearContents)
        QtCore.QMetaObject.connectSlotsByName(TEcalcGUI)

    def retranslateUi(self, TEcalcGUI):
        TEcalcGUI.setWindowTitle(
            QtGui.QApplication.translate("TEcalcGUI", "Tao-Eldrup Calculator",
                                         None, QtGui.QApplication.UnicodeUTF8))
        self.groupBox_2.setTitle(
            QtGui.QApplication.translate("TEcalcGUI", "Inputs", None,
                                         QtGui.QApplication.UnicodeUTF8))
        self.label.setText(
            QtGui.QApplication.translate("TEcalcGUI", "Lifetimes", None,
                                         QtGui.QApplication.UnicodeUTF8))
        self.nsRB.setText(QtGui.QApplication.translate("TEcalcGUI", "ns", None,
                                                       QtGui.QApplication.UnicodeUTF8))
        self.psRB.setText(QtGui.QApplication.translate("TEcalcGUI", "ps", None,
                                                       QtGui.QApplication.UnicodeUTF8))
        self.label_2.setText(
            QtGui.QApplication.translate("TEcalcGUI", "Temperatures", None,
                                         QtGui.QApplication.UnicodeUTF8))
        self.kelvinRB.setText(
            QtGui.QApplication.translate("TEcalcGUI", "Kelvin", None,
                                         QtGui.QApplication.UnicodeUTF8))
        self.celsiusRB.setText(
            QtGui.QApplication.translate("TEcalcGUI", "Celsius", None,
                                         QtGui.QApplication.UnicodeUTF8))
        self.groupBox.setTitle(
            QtGui.QApplication.translate("TEcalcGUI", "Pore geometry", None,
                                         QtGui.QApplication.UnicodeUTF8))
        self.GeomSphereRB.setToolTip(QtGui.QApplication.translate("TEcalcGUI",
                                                                  "<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
                                                                  "p, li { white-space: pre-wrap; }\n"
                                                                  "</style></head><body style=\" font-family:\'MS Shell Dlg 2\'; font-size:8.25pt; font-weight:400; font-style:normal;\">\n"
                                                                  "<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:8pt;\">Spherical pores. </p>\n"
                                                                  "<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:8pt;\">The <span style=\" font-weight:600;\">original</span> Tao-Eldrup model is used.</p></body></html>",
                                                                  None,
                                                                  QtGui.QApplication.UnicodeUTF8))
        self.GeomSphereRB.setText(
            QtGui.QApplication.translate("TEcalcGUI", "Sphere (TE)", None,
                                         QtGui.QApplication.UnicodeUTF8))
        self.GeomEquivSphRB.setToolTip(QtGui.QApplication.translate("TEcalcGUI",
                                                                    "<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
                                                                    "p, li { white-space: pre-wrap; }\n"
                                                                    "</style></head><body style=\" font-family:\'MS Shell Dlg 2\'; font-size:8.25pt; font-weight:400; font-style:normal;\">\n"
                                                                    "<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:8pt;\">The rectangular Tao-Eldrup model is used to obtain a cubic pore size. Then the cube size is converted to an sphere of equivalent mean free path.</p></body></html>",
                                                                    None,
                                                                    QtGui.QApplication.UnicodeUTF8))
        self.GeomEquivSphRB.setText(
            QtGui.QApplication.translate("TEcalcGUI", "Equiv Sphere (RTE)",
                                         None, QtGui.QApplication.UnicodeUTF8))
        self.GeomCubeRB.setToolTip(QtGui.QApplication.translate("TEcalcGUI",
                                                                "<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
                                                                "p, li { white-space: pre-wrap; }\n"
                                                                "</style></head><body style=\" font-family:\'MS Shell Dlg 2\'; font-size:8.25pt; font-weight:400; font-style:normal;\">\n"
                                                                "<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">Cubic pore.</p>\n"
                                                                "<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">The <span style=\" font-weight:600;\">Rectangular</span> Tao-Eldrup mode is used.</p></body></html>",
                                                                None,
                                                                QtGui.QApplication.UnicodeUTF8))
        self.GeomCubeRB.setText(
            QtGui.QApplication.translate("TEcalcGUI", "Cube", None,
                                         QtGui.QApplication.UnicodeUTF8))
        self.GeomChannelRB.setToolTip(QtGui.QApplication.translate("TEcalcGUI",
                                                                   "<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
                                                                   "p, li { white-space: pre-wrap; }\n"
                                                                   "</style></head><body style=\" font-family:\'MS Shell Dlg 2\'; font-size:8.25pt; font-weight:400; font-style:normal;\">\n"
                                                                   "<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">Infinitelly long, square section channel.</p>\n"
                                                                   "<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">The <span style=\" font-weight:600;\">Rectangular</span> Tao-Eldrup mode is used.</p></body></html>",
                                                                   None,
                                                                   QtGui.QApplication.UnicodeUTF8))
        self.GeomChannelRB.setText(
            QtGui.QApplication.translate("TEcalcGUI", "Square Channel", None,
                                         QtGui.QApplication.UnicodeUTF8))
        self.GeomSheetRB.setToolTip(QtGui.QApplication.translate("TEcalcGUI",
                                                                 "<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
                                                                 "p, li { white-space: pre-wrap; }\n"
                                                                 "</style></head><body style=\" font-family:\'MS Shell Dlg 2\'; font-size:8.25pt; font-weight:400; font-style:normal;\">\n"
                                                                 "<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">Infinitelly wide, planar pore.</p>\n"
                                                                 "<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:8pt;\">The <span style=\" font-weight:600;\">Rectangular</span> Tao-Eldrup mode is used.</p></body></html>",
                                                                 None,
                                                                 QtGui.QApplication.UnicodeUTF8))
        self.GeomSheetRB.setText(
            QtGui.QApplication.translate("TEcalcGUI", "Sheet", None,
                                         QtGui.QApplication.UnicodeUTF8))
        self.softwallsCB.setToolTip(QtGui.QApplication.translate("TEcalcGUI",
                                                                 "<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
                                                                 "p, li { white-space: pre-wrap; }\n"
                                                                 "</style></head><body style=\" font-family:\'MS Shell Dlg 2\'; font-size:8.25pt; font-weight:400; font-style:normal;\">\n"
                                                                 "<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:8pt;\">The TE model (as well as the RTE) introduce the concept of \"soft potential walls\". </p>\n"
                                                                 "<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:8pt;\">If this option is checked, the \"soft wall\" width will be included in the reported size.</p></body></html>",
                                                                 None,
                                                                 QtGui.QApplication.UnicodeUTF8))
        self.softwallsCB.setText(
            QtGui.QApplication.translate("TEcalcGUI", "Include \"soft walls\"",
                                         None, QtGui.QApplication.UnicodeUTF8))
        self.tauTE.setToolTip(QtGui.QApplication.translate("TEcalcGUI",
                                                           "<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
                                                           "p, li { white-space: pre-wrap; }\n"
                                                           "</style></head><body style=\" font-family:\'MS Shell Dlg 2\'; font-size:8.25pt; font-weight:400; font-style:normal;\">\n"
                                                           "<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">Fill with lifetime values.</p>\n"
                                                           "<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">Lists of values can be separated by spaces, carriage returns, tabulators or semicolons</p></body></html>",
                                                           None,
                                                           QtGui.QApplication.UnicodeUTF8))
        self.TempTE.setToolTip(QtGui.QApplication.translate("TEcalcGUI",
                                                            "<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
                                                            "p, li { white-space: pre-wrap; }\n"
                                                            "</style></head><body style=\" font-family:\'MS Shell Dlg 2\'; font-size:8.25pt; font-weight:400; font-style:normal;\">\n"
                                                            "<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">Fill with temperature values if you are using the Rectangular Tao-Eldrup model.</p>\n"
                                                            "<p style=\"-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"></p>\n"
                                                            "<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">Lists of values can be separated by spaces, carriage returns, tabulators or semicolons.</p>\n"
                                                            "<p style=\"-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"></p>\n"
                                                            "<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">If you want to calculate many lifetimes for the same temperature, enter a single value here and check the \"Same temp.\" option below.</p></body></html>",
                                                            None,
                                                            QtGui.QApplication.UnicodeUTF8))
        self.TempTE.setHtml(QtGui.QApplication.translate("TEcalcGUI",
                                                         "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
                                                         "<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
                                                         "p, li { white-space: pre-wrap; }\n"
                                                         "</style></head><body style=\" font-family:\'MS Shell Dlg 2\'; font-size:8.25pt; font-weight:400; font-style:normal;\">\n"
                                                         "<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:8pt;\">0</p></body></html>",
                                                         None,
                                                         QtGui.QApplication.UnicodeUTF8))
        self.sameTempCB.setToolTip(QtGui.QApplication.translate("TEcalcGUI",
                                                                "<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
                                                                "p, li { white-space: pre-wrap; }\n"
                                                                "</style></head><body style=\" font-family:\'MS Shell Dlg 2\'; font-size:8.25pt; font-weight:400; font-style:normal;\">\n"
                                                                "<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">Enable this if you want to use a single temperature value for all the calculations.</p></body></html>",
                                                                None,
                                                                QtGui.QApplication.UnicodeUTF8))
        self.sameTempCB.setText(
            QtGui.QApplication.translate("TEcalcGUI", "Same temp. for all",
                                         None, QtGui.QApplication.UnicodeUTF8))
        self.ClearPB.setToolTip(QtGui.QApplication.translate("TEcalcGUI",
                                                             "<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
                                                             "p, li { white-space: pre-wrap; }\n"
                                                             "</style></head><body style=\" font-family:\'MS Shell Dlg 2\'; font-size:8.25pt; font-weight:400; font-style:normal;\">\n"
                                                             "<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">Clear the Lifetime and Temperature inputs, as well as the results.</p></body></html>",
                                                             None,
                                                             QtGui.QApplication.UnicodeUTF8))
        self.ClearPB.setText(
            QtGui.QApplication.translate("TEcalcGUI", "Clear", None,
                                         QtGui.QApplication.UnicodeUTF8))
        self.groupBox_3.setTitle(
            QtGui.QApplication.translate("TEcalcGUI", "Output", None,
                                         QtGui.QApplication.UnicodeUTF8))
        self.resultsTable.setToolTip(QtGui.QApplication.translate("TEcalcGUI",
                                                                  "<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
                                                                  "p, li { white-space: pre-wrap; }\n"
                                                                  "</style></head><body style=\" font-family:\'MS Shell Dlg 2\'; font-size:8.25pt; font-weight:400; font-style:normal;\">\n"
                                                                  "<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">Results.</p>\n"
                                                                  "<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">You can copy them all by selecting the desired results and using the context menu option.</p></body></html>",
                                                                  None,
                                                                  QtGui.QApplication.UnicodeUTF8))
        self.resultsTable.clear()
        self.resultsTable.setColumnCount(3)
        self.resultsTable.setRowCount(0)
        headerItem = QtGui.QTableWidgetItem()
        headerItem.setText(
            QtGui.QApplication.translate("TEcalcGUI", "Lifetime (ns)", None,
                                         QtGui.QApplication.UnicodeUTF8))
        self.resultsTable.setHorizontalHeaderItem(0, headerItem)
        headerItem1 = QtGui.QTableWidgetItem()
        headerItem1.setText(
            QtGui.QApplication.translate("TEcalcGUI", "Temperature (K)", None,
                                         QtGui.QApplication.UnicodeUTF8))
        self.resultsTable.setHorizontalHeaderItem(1, headerItem1)
        headerItem2 = QtGui.QTableWidgetItem()
        headerItem2.setText(
            QtGui.QApplication.translate("TEcalcGUI", "Size (nm)", None,
                                         QtGui.QApplication.UnicodeUTF8))
        self.resultsTable.setHorizontalHeaderItem(2, headerItem2)
        self.CalculatePB.setText(
            QtGui.QApplication.translate("TEcalcGUI", "Calculate", None,
                                         QtGui.QApplication.UnicodeUTF8))
        self.actionCopy_Results_Selection.setText(
            QtGui.QApplication.translate("TEcalcGUI", "Copy_Results_Selection",
                                         None, QtGui.QApplication.UnicodeUTF8))


import PAScual_rc



''' Tests of installation'''
'''
	This file is part of PAScual.
    PAScual: Positron Annihilation Spectroscopy data analysis
    Copyright (C) 2007  Carlos Pascual-Izarra < cpascual [AT] users.sourceforge.net >

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
'''

print "Testing the required Python packages"

##print '**Required for PAScual.py'
print '\nnumpy...',
try:
    import numpy as t1
except:
    print "Failed"
else:
    print 'ok, version:', t1.version.version

print '\nscipy...',
try:
    import scipy as t2
except:
    print "Failed"
else:
    print 'ok, version:', t2.version.version

##print '**Required for graphs in text mode'

print '\nmatplotlib...',
try:
    import matplotlib as t3
except:
    print "Failed"
else:
    print 'ok, version:', t3.__version__

##print '**Required for PAScualGUI.py'

print '\nPyQt...',
try:
    import PyQt4.QtCore as t4
    import PyQt4.QtGui as t4b
except:
    print "Failed"
else:
    print 'ok, version:', t4.PYQT_VERSION_STR

print '\nPyQwt...',
try:
    import PyQt4.Qwt5 as t5
except:
    print "Failed"
else:
    print 'ok, version:', t5.QWT_VERSION_STR

print '\n\nTesting PAScual.py',
try:
    import PAScual as t6
except:
    print "Failed"
else:
    print 'ok, version:', t6.__version__

print '\n\nTesting PAScualGUI.py',
try:
    import PAScualGUI as t7
except:
    print "Failed"
else:
    print 'ok, version:', t7.__version__

raw_input('\n\nPress <Enter> key to finish')



### Input parameters for PAScual.
### by Carlos Pascual-Izarra < cpascual [AT] users.sourceforge.net >  2007
### '''
### 	This file is part of PAScual.
###     PAScual: Positron Annihilation Spectroscopy data analysis
###     Copyright (C) 2007  Carlos Pascual-Izarra < cpascual [AT] users.sourceforge.net >
###
###     This program is free software: you can redistribute it and/or modify
###     it under the terms of the GNU General Public License as published by
###     the Free Software Foundation, either version 3 of the License, or
###     (at your option) any later version.
###
###     This program is distributed in the hope that it will be useful,
###     but WITHOUT ANY WARRANTY; without even the implied warranty of
###     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
###     GNU General Public License for more details.
###
###     You should have received a copy of the GNU General Public License
###     along with this program.  If not, see <http://www.gnu.org/licenses/>.
### '''


#########DO NOT TOUCH THIS BLOCK ##############################
from glob import glob as matchfilenames
from scipy import inf, array, arange, log, exp, concatenate, savetxt

############# END OF "DO-NOT-TOUCH" BLOCK #####################


######### In principle, this is the only file you need to touch for a regular calculation
######### You can modify the parameters below this line

######### IMPORTANT NOTES ON SYNTAX FOR THIS FILE:
# # 1- Regular Python syntax format applies. The hash "#" character is a comment. You can call Python functions and operators if you want.
# # 2- Parameters marked with (*1) can optionally be given as a list (for multiple spectra fit). 
# #    If a non-list value is provided it will be used for all the spectra.
# # 3- Parameters marked with (*2) are direct descriptions of fitting parameters. They can be one of the following values:
# #    a) a string being the name of a named parameter, with an optional "*" for making common parameters (see the named parameter section below)
# #    b) a single numerical value. This means that the parameter is FIXED (non-free).
# #    c) a tuple containing (value,minimum,maximum). This means it is a free parameter.
# # 4- Parameters marked with (*3) accept the same syntax as those with (*1) except in that they are extended over the number of 
# #    palssets (instead of the number of spectra). Note that the palssets are automatically created by optimally distributing the 
# #    given spectra. Therefore, the usage of lists for these parameters is only for very advanced users who know what they are doing

##=================================================================================================================================================
######Experimental data 
#### Indicate which experimental data is going to be analysed.  You can make use of a path variable. 
#### You can also use the matchfilenames() function in order to use wildcards: *, ?, [-],....
# expfilenames=['data/KansyA.dat'] 	#(*1) list of names (optionally with a path) for the experimental file(s) 
# expfilenames=['data/KansyA.dat','data/KansyB.dat','data/KansyC.dat','data/KansyD.dat']
# path="C:\Documents and Settings\pas064\My Documents\PALS\Aurelia\Al holder\PHYT_T20/selectedsums/"
# path="C:\Documents and Settings\pas064\My Documents\PALS\Aurelia\Al holder\PHYT_T20/"
path = './examples/'

# expfilenames=[]
# expfilenames=matchfilenames(path+'Pure*/??_???*sum.al2')
# expfilenames+=matchfilenames(path+'3%*/??_???*sum.al2')
# expfilenames+=(matchfilenames(path+'5%*/??_???*sum.al2')+matchfilenames(path+'5%*/05B_???.al2'))
# expfilenames+=matchfilenames(path+'8%*/08_???.al2')
# expfilenames+=matchfilenames(path+'11%*/??_???*sum.al2')
# expfilenames+=matchfilenames(path+'13/??_???.al2')
# expfilenames+=matchfilenames(path+'15/??_???*sum.al2')
# expfilenames+=matchfilenames(path+'17/??_???.al2')
# expfilenames+=matchfilenames(path+'19/??_???.al2')
# expfilenames+=matchfilenames(path+'22/??_???.al2')
# expfilenames+=matchfilenames(path+'25/??_???.al2')
# expfilenames+=matchfilenames(path+'26/??_???.al2')[:10]
# expfilenames+=matchfilenames(path+'27/??_???.al2')
# expfilenames+=matchfilenames(path+'28/??_???.al2')[:10]


expfilenames = matchfilenames(path + '*.dat')

# expfilenames+=matchfilenames(path+'CPI_A_*.dat')
# expfilenames=5*[None]

# skipfilenames=(matchfilenames(path+'28_1??.al2')) # list of file names names to ignore (useful if matchfilenames() returned some unwanted file names)
headerlines = 4  # (*1) Number of rows to skip when reading the exp file (to skip the header). Put to 0 if no header.

####### Calibration.
psperchannel = 50  # (*1) Channel width in picoseconds.

######ROI definition.
#### Any roi can be given. Just do an array (or list) containing channel numbers in the ROI. 
#### Examples:
# roi=arange(213,879)  				#roi between channels 10 and 800
# roi=range(10,200)+range(400,500)  #roi defined in by two subranges 							# (*1) The whole spectrum
#### OR, ALTERNATIVELY, instead of directly defining the roi, you can define the left_of_max and stopdat variables as in MELT. 
left_of_max = 5  # (*1) Start this much at the left of the channel with the max number of counts.
stopdat = 689  # (*1) Channel where the data stops.

####### Named parameters
#### For convenience, it is possible to assign a name to a parameter. 
#### This is done in a "dictionary": {'parname1':(val1,min1,max1), 'parname2':(val2,min2,max2),...}
#### The parameters defined here can be later referred to by their name.
#### When **referring** to the parameter, if just its name is used, a unique COPY of that parameter will be used and
#### therefore that parameter will be independent (as opposed to "common")
#### On the other hand, if a "*" is appended to the name when referring to it, a copy is NOT made (allowing to have common parameters)

namedparameters = {
    'fwhm': (270, 100, 500),
    'c0': (30, 10, 100),
    'bg': (20, 1, 1000),
    'tau_pPs': (125, 50, 250), 'tau_drt': (400, 250, 600),
    'tau_oPs': (3000, 600, 142e3),
    'tau1': (125, 50, 350), 'tau2': (400, 150, 600), 'tau3': (1900, 500, 142e3),
    'tau': (300, psperchannel, 142e3), 'tauKansy': (300, psperchannel, 142e3),
    'ity': (1, 0, None), 'ityKansy': (1, 0, None),
    'tau4': (1300, 800, 5000), 'at1': (1500, 1000, 4000), 'at2': 1.7,
    'tausrc': 1630, 'itysrc': .066, 'tauH2O': (1800, 1600, 2000),
    'tauPHYT': (2800, 2000, 3500)}

######Background.
####Note: unless you fix the background, it doesn't really matter to give a precise value.
# bg=(100,0,1e4)			# (*1)(*2) 
#### ALTERNATIVELY: If the baseline is present in a region of your spectrum, you can just give its starting and end channels
####                In this case, it is assumed to be free non-common parameter(s)  and the min and max will be automatically calculated
startbg = 660  # (*1) first bin for background initialisation
stopbg = 680  # (*1) last bin for background initialisation
# bg=(20,1,200)
# bg=25*5
# bg=[5e-5*1e6*float(a) for a in areaList ]
# print bg
# raw_input()

###### FWHM. 
#### Resolution function Full Width Half Maximum in ps (assuming Gaussian shape)
# fwhm=(300,200,400)  # (*1)(*2) FWHM
# fwhm="fwhm"
fwhm = (280, None, None)
# fwhm=270

###### Offset. 
#### Channel for time 0. 
# c0=(100,10,500)  # (*1)(*2)  Calibration offset. If omitted, it will be assumed to be a free non-common parameter and (val,min,max) will be automatically calculated
# c0=[20,"c0","c0",20]
# c0=100


####### Lifetimes
#### Define the lifetimes as a TUPLE of fitpar descriptors, i.e., as (t1,t2,t3,...),  where ti is one of the cases described by (*2)
#### note that a "list of tuples of descriptors" is also possible just following (*1)
tau = ((100, 50, 200), (400, 200, 500), (
1000, 500, 1.42e5))  # (*1)(*2) lifetimes in ps.  Note, min>0 and max<1.42e5ps
# tau=[("tau1","tau2","tau3",1000), ("tau1","tau2","tau3",1050)]+2*[(234,"Ctau2")]
# tau=[("tau1","tau2","tau3","tau4")]+2*[(234,"Ctau2")]
# tau=('tau1*','tau2*','tau3*',(1140,50,150000))
# tau=[((100,psperchannel,142e3),(300,psperchannel,142e3),(500,psperchannel,142e3),(5000,psperchannel,142e3))]+3*[('tau','tau')]
# tau=[((100,psperchannel,142e3),(300,psperchannel,142e3),(500,psperchannel,142e3),(5000,psperchannel,142e3))]
# tau=[('tau','tau','tau','tau')]+3*[('tauKansy*','tau')]
# tau=[((100,50,180),(180,170,300))]
# tau=[('tau','tau')]
# tau=[('tau','tau','tau','tau')]
# tau=(125,"tau_drt","tau_oPs","tauPHYT")
# tau=(125,"tau_drt","tau_oPs",1905,418)
# tau=(125, (400,1,142e3), 1800, (3000,1,142e3))
# ity=('ity','ity',.05,'ity')
# tau=[(125, 'tau_drt', 'tauH2O', t) for t in tarray]
# ity=(.15,  .20 , .05,   .60)
# ity=(.20,.60,.20)
# ity=(.25,.25,.25,.25)
# tau=(125,'tau','tau')


####### Intensities
#### You can define the lifetimes as a tuple, including common parameters
# ity=None		# (*1)(*2) Same syntax as for tau. (if omitted, it will be initialised as val=1,min=0,max=inf)
# ity=[('ity','ity','ity','ity')]+3*[('ityKansy*','ity*')]
# ity=('ity','ity','ity','ity',)
# ity=('ity','ity','ity',0.035,0.155)
##=================================================================================================================================================

####### Fitology:
#### These parameters control the way the fitting is done. 
#### Three tools are implemented for fitting: Simulated annealing (SA), Bayesian Inference (BI) and Local Search (LOCAL). 
#### Read the documentation to find out about each of them.
#### Rougthly speaking: SA is good to find the global minimum but it is slow (use it as an initialisation tool).
####					BI should be run after the global minimum is found in order to calculate the errors. Use it after SA
####					LOCAL is not robust but it is fast once you are near the minimum. Use it after SA. 

fitmode = ('LOCAL', 'LOG ' + path + 'results.txt')
# fitmode=('LOAD','SA','LOCAL','BI','SAVE')
# fitmode=('LOAD','BI','REPORT','SAVE')
# fitmode=[('SA','SAVE kk0_SA','BI','SAVE kk0_BI','LOCAL','SAVE kk0_LOCAL'),('SA','SAVE kk1_SA','BI','SAVE kk1_BI','LOCAL','SAVE kk1_LOCAL'),('SA','SAVE kk2_SA','BI','SAVE kk2_BI','LOCAL','SAVE kk2_LOCAL'),('SA','SAVE kk3_SA','BI','SAVE kk3_BI','LOCAL','SAVE kk3_LOCAL')]
# fitmode=[('LOAD kk0_SA','REPORT','LOAD kk0_BI','REPORT'),('LOAD kk1_SA','REPORT','LOAD kk1_BI','REPORT'),('LOAD kk2_SA','REPORT','LOAD kk2_BI','REPORT'),('LOAD kk3_SA','REPORT','LOAD kk3_BI','REPORT')]
# fitmode=('LOAD','LOCAL','SAVE','LOG '+path+'dp-allfree.dat')
# fitmode=('SA','LOG '+path+'kk.dat')					
# fitmode=[('SA','SAVE','LOCAL','LOG '+path+'kk.dat',)]+[('LOAD','LOCAL','LOG '+path+'kk.dat',)]*(len(expfilenames)-1)
# fitmode=('LOAD','LOCAL','SAVE','LOG '+path+'results.txt')					
# fitmode=[('LOCAL','LOG '+path+'results.txt','SAVE %s_SA.sav'%fn) for fn in expfilenames]	
# fitmode=('SA','LOG '+path+'results.txt')					
# fitmode=[('FAKE 2e7 %sCPI_A_%03i.dat'%(path,i+1),'LOG %sCPI_A_perfect.txt'%path) for i in range(len(expfilenames))]
# fitmode=[('FAKE 2e6 %sCPI_D_%03i.dat'%(path,i+1),'LOG %sCPI_D_perfect.txt'%path) for i in range(len(expfilenames))]
# fitmode=[('FAKE 5e5 %sCPI_G_%03i.dat'%(path,i),'LOG %sCPI_G_perfect.txt'%path) for i in T]
# fitmode=[('FAKE 5e5 %sCPI_G_%03i_%03i.dat'%(path,T[i],i%nrepeats),'LOG %sCPI_G_perfect.txt'%path) for i in xrange(T.size)]
# fitmode=[('FAKE 25e5 %sCPI_J_%02i_%03i.dat'%(path,int(ity4[i]*100),i%nrepeats),'LOG %sCPI_J_perfect.txt'%path) for i in xrange(ity4.size)]
# fitmode=[('FAKE %f %sCPI_F_%s.dat'%(float(A)*1e6,path,A),'LOG %sCPI_F_perfect.txt'%path) for A in areaList]
# fitmode=('LOAD','LOCAL NOLIMITS','SAVE','LOG '+path+'CPI_A_results.txt')
# fitmode=('LOCAL NOLIMITS','LOG '+path+'CPI_A_results.txt')
# fitmode=('LOCAL','LOG kk')	

######Output 
###Output data file. See following examples:
# outputfile=path+'output.txt' #a name
outputfile = None  # no output file creation
# outputfile=expfilename.rsplit('.',1)[0]+'.out' #same as the experimental but with .out extension
# outputfile=expfilename.rsplit('.',1)[0]+'20.out'
BI_report = 500  # A report will be shown every this steps during BI (put to -1 for no reports). Be Careful: too much reports may slow down the calc.

####Advanced fitting parameters
#### IMPORTANT:
#### The following parameters are not supposed to be changed by regular users. They deal with internal algorithmical choices.
#### The default values are generally correct. Don't mess with them if you don't know exactly what you are doing
SA_tol = 1e-5  # (*3)Tolerance for stopping the SA
SA_stopT = .1  # (*3)Stop temperature for SA (put to 0 to disable). (SA_stopT>1 is not recommended)
SA_maxiter = inf  # (*3)Max number of iterations in the SimAnn fit
SA_direct = True  # (*3)Whether to use the direct mode in NNRLA for SA. Note: If SA_NNRLA=False (or <=0), SA_direct is ignored.
SA_meltratio = 0.97  # (*3)The "melting" phase of the SA will stop when this acceptance ratio is reached

LOCAL_tol = 0  # (NOT USED) (*3)Local search tolerance (the lower, the more time it will take). Put this to 0 to skip Local search and ~1e-5 for calculating
LOCAL_maxiter = 1e5  # (NOT USED) (*3)Max number of iterations in the LOCAL fit.

BI_stab = 5000  # (*3)This much steps (multiplied by the order of the searching space!) of BI will be done and not considered for statistical purposes. Put this to 0 to skip stabilisation.
BI_length = 50000  # (*3)This much steps (multiplied by the order of the searching space) will be calculated by BI.
seed = 1345  # Seed for pseudorandom generator

if __name__ == '__main__':
    from PAScual import *

    try:
        import pylab
    except:
        print >> sys.stderr, "Pylab could not be imported. Graphical output won't be supported"
    safemain()



import os
from setuptools import setup, find_packages


# entry points to create scripts
entry_points={
    'console_scripts': [
        'pascual_batch = PAScual.PAScual:start',
    ],
    'gui_scripts': [
        'pascual = PAScual.PAScualGUI:main',
        'pascual_TEcalc = PAScual.TEcalcGUI:main',
    ]
}

# classifiers
classifiers = [
    "Development Status :: 5 - Production/Stable",
    "Environment :: X11 Applications :: Qt",
    "Environment :: Win32 (MS Windows)",
    "Intended Audience :: Science/Research",
    "License :: OSI Approved :: GNU General Public License v3 or later (GPLv3+)",
    "Natural Language :: English",
    "Operating System :: OS Independent",
    "Programming Language :: Python :: 2 :: Only",
    "Topic :: Scientific/Engineering",
]

# call setup()
setup(
    name='PAScual',
    version='1.7.1',
    url='https://sourceforge.net/p/pascual/w/Main_Page/',
    license='GPLv3',
    author='Carlos Pascual-Izarra',
    author_email='cpascual@users.sourceforge.net',
    description='Positron Annihilation Spectroscopy data analysis',
    long_description=open(os.path.join(os.path.dirname(__file__),
                                       'README.txt')).read(),
    keywords = "science PALS PAS positron annihilation fit",

    packages=find_packages(),
    entry_points=entry_points,
    install_requires=['numpy'],
    classifiers=classifiers,

)

